==========
Charlesbot
==========

.. image:: https://img.shields.io/travis/marvinpinto/charlesbot/master.svg?style=flat-square
    :target: https://travis-ci.org/marvinpinto/charlesbot
    :alt: Travis CI
.. image:: https://img.shields.io/coveralls/marvinpinto/charlesbot/master.svg?style=flat-square
    :target: https://coveralls.io/github/marvinpinto/charlesbot?branch=master
    :alt: Code Coverage
.. image:: https://img.shields.io/pypi/dm/charlesbot.svg?style=flat-square
    :target: https://pypi.python.org/pypi/charlesbot
    :alt: PyPI
.. image:: https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat-square
    :target: LICENSE.txt
    :alt: Software License

CharlesBOT is a Python bot written to take advantage of Slack's `Real Time
Messaging`__ API.

__ https://api.slack.com/rtm

Documentation available at `https://charlesbot.org`__.

__ https://charlesbot.org
